@@ -1,6 +1,6 @@
 #'@export
 #'@import boot
-.gp.pw.fit=function(data,init,CI=T,R=200,ncpus=1){
+.gp.pw.fit=function(data,init,CI=T,R=R,ncpus=ncpus){
   x <- seq(0,max(data),by=0.05);
   dEGPs <- c();
   qEGPs <- c();
@@ -8,6 +8,9 @@
   fit.PWM <- .EGP.fitPWM(x=data,kappa0=init[1],sigma0=init[2],xi0=init[3]);
   if(CI){
     fit.PWM.boot <- boot::boot(data=data,statistic=.EGP.fitPWM.boot,R=R,kappa0=init[1],sigma0=init[2],xi0=init[3],parallel="multicore",ncpus=ncpus);
+
+
+
     CI.PWM.kappa <- boot::boot.ci(boot.out=fit.PWM.boot,index=1,type="perc")$perc[4:5];
     CI.PWM.sigma <- boot::boot.ci(boot.out=fit.PWM.boot,index=2,type="perc")$perc[4:5];
     CI.PWM.xi <- boot::boot.ci(boot.out=fit.PWM.boot,index=3,type="perc")$perc[4:5];
